"""Module for the number detector."""

from typing import Any, Dict, List, Tuple

import regex as re

from src.detections import NumberDetection
from src.detectors.interface import Detector

NUMBER_REGEX = re.compile(
    r"\d+",
    re.I,
)


class NumberDetector(Detector):
    """Detector for numbers."""

    def detect(
        self, text: str, annotations: Dict[str, List[Tuple[int, int, Any]]]
    ) -> List[Tuple[int, int, NumberDetection]]:
        """Detects numbers in the text.

        Args:
            text (str): the text to be searched
            annotations (Dict[str, List[Tuple[int, int, Any]]]): Annotations of
                the text

        Returns:
            List[Tuple[int, int, NumberDetection]]: a list of tuples containing
                (start, end, entity_type)

        """
        numbers = []

        for number in NUMBER_REGEX.finditer(text):
            numbers.append((number.start(), number.end(), NumberDetection()))

        return numbers
